@@ -20,10 +20,8 @@
 #include "historyptrlist.h"
 
 class QAction;
-class KListAction;
 class KProcess;
 class QStatusBar;
-class KStatusNotifierItem;
 class KToggleAction;
 class KitenConfigSkeleton;
 
@@ -46,7 +44,6 @@ public:
 
     KitenConfigSkeleton *getConfig();
 
-    // The following will be available via dbus.
 public Q_SLOTS:
     void searchTextAndRaise(const QString &str);
     void addExportListEntry(int index);
@@ -69,14 +66,10 @@ private Q_SLOTS:
     void displayResults(EntryList *);
     void radicalSearch();
     void kanjiBrowserSearch();
-    // void searchOnTheSpot();
 
     // Configuration related slots
     void slotConfigure();
-    void slotConfigureHide();
-    void slotConfigureDestroy();
     void configureToolBars();
-    void configureGlobalKeys();
     void newToolBarConfig();
     void updateConfiguration();
     void loadDictionaries();
@@ -94,13 +87,6 @@ private Q_SLOTS:
     void enableHistoryButtons();
     void setCurrentScrollValue(int value);
 
-    //	void createEEdit();
-    //	void kanjiDictChange();
-    //	void slotLearnConfigure();
-    // Q_SIGNALS:
-    //	void saveLists();
-    //	void add( Entry* );
-
 private:
     QStatusBar *_statusBar = nullptr;
     DictionaryManager _dictionaryManager;
@@ -110,21 +96,12 @@ private:
 
     DictQuery _lastQuery;
     KToggleAction *_autoSearchToggle = nullptr;
-    KListAction *_historyAction = nullptr;
     QAction *_irAction = nullptr;
     QAction *_backAction = nullptr;
     QAction *_forwardAction = nullptr;
     KProcess *_radselect_proc = nullptr;
     KProcess *_kanjibrowser_proc = nullptr;
 
-    // TODO: this should probably be a standardaction
-    QAction *_globalShortcutsAction = nullptr;
-
-    // ResultsView *detachedView;
-    QAction *_globalSearchAction = nullptr;
-
-    KStatusNotifierItem *_sysTrayIcon = nullptr;
-
     // Export list related:
     QDockWidget *_exportListDock = nullptr;
     QWidget *_exportListDockContents = nullptr;
