@@ -10,7 +10,9 @@
 
 #include <QDebug>
 #include <QFile>
-#include <QTextCodec>
+#include <QStringDecoder>
+
+using namespace Qt::StringLiterals;
 
 LinearEdictFile::LinearEdictFile()
     : m_properlyLoaded(false)
@@ -46,13 +48,15 @@ bool LinearEdictFile::loadFile(const QString &filename)
         return false;
     }
 
-    QTextStream fileStream(&file);
-    fileStream.setCodec(QTextCodec::codecForName("eucJP"));
+    QStringDecoder decoder("EUC-JP");
+    const QString decoded = decoder(file.readAll());
+
+    QTextStream fileStream(decoded.toUtf8());
 
     QString lastLine;
     while (!fileStream.atEnd()) {
         lastLine = fileStream.readLine();
-        if (lastLine[0] != '#')
+        if (lastLine[0] != '#'_L1)
             m_edict << lastLine;
     }
 
